/**
 * @internal
 *
 * The XML parser will set one K:V for a member that could
 * return multiple entries but only has one.
 */
export declare const getArrayIfSingleItem: <T>(mayBeArray: T) => T | T[];
