/**
 * @internal
 *
 * Maps an object through the default JSON serde behavior.
 * This means removing nullish fields and un-sparsifying lists.
 *
 * This is also used by Smithy RPCv2 CBOR as the default serde behavior.
 *
 * @param obj - to be checked.
 * @returns same object with default serde behavior applied.
 */
export declare const _json: (obj: any) => any;
