import { Client } from "./client";
/**
 * @internal
 *
 * @param commands - command lookup container.
 * @param client - client instance on which to add aggregated methods.
 * @returns an aggregated client with dynamically created methods.
 */
export declare const createAggregatedClient: (commands: Record<string, any>, Client: {
    new (...args: any): Client<any, any, any, any>;
}) => void;
